telegram package
================

Submodules
----------

telegram.client module
----------------------

.. automodule:: telegram.client
    :members:
    :undoc-members:
    :show-inheritance:

telegram.tdjson module
----------------------

.. automodule:: telegram.tdjson
    :members:
    :undoc-members:
    :show-inheritance:

telegram.utils module
---------------------

.. automodule:: telegram.utils
    :members:
    :undoc-members:
    :show-inheritance:

telegram.worker module
----------------------

.. automodule:: telegram.worker
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: telegram
    :members:
    :undoc-members:
    :show-inheritance:
